@@ -1,7 +1,6 @@
 # file: example.tcl
 
-catch { load ./example.so example}
-catch { load ./example.dll example}    ;# Windows
+catch { load ./example[info sharedlibextension] example}
 
 set a 37
 set b 42
